mod parser;

#[macro_use]
extern crate rocket;

use rocket::serde::json::Json;
use crate::parser::lsblk_parser::{Disk, parse_lsblk};
use crate::parser::mdstat_parser::{MdRaidSystem, parse_mdstat};

#[get("/raiddevices")]
fn get_raid_devices() -> Json<MdRaidSystem> {
    Json(parse_mdstat())
}

#[get("/disks")]
fn get_disks() -> Json<Vec<Disk>> {
    Json(parse_lsblk())
}

#[rocket::main]
async fn main() -> Result<(), rocket::Error> {
    println!("init");
    let _rocket = rocket::build()
        .mount("/api", routes![get_raid_devices, get_disks])
        .launch()
        .await?;

    Ok(())
}